The `vcreview` cube provides a code review system on top of the `vcsfile
cube`_. It has been developped with the workflow we use at Logilab_ in mind, based
on `mercurial`_ and its `mq`_ extension.


.. _`vcsfile cube`: http://www.cubicweb.org/project/cubicweb-vcsfile
.. _`mercurial`: http://mercurial.selenic.com
.. _`mq`: http://mercurial.selenic.com/wiki/MqExtension
.. _Logilab: http://www.logilab.fr
